@@ -91,6 +91,10 @@ module Spring
 
       require Spring.application_root_path.join("config", "application")
 
+      unless Rails.respond_to?(:gem_version) && Rails.gem_version >= Gem::Version.new('4.2.0')
+        raise "Spring only supports Rails >= 4.2.0"
+      end
+
       # config/environments/test.rb will have config.cache_classes = true. However
       # we want it to be false so that we can reload files. This is a hack to
       # override the effect of config.cache_classes = true. We can then actually
@@ -147,7 +151,7 @@ module Spring
       log "got client"
       manager.puts
 
-      stdout, stderr, stdin = streams = 3.times.map { client.recv_io }
+      _stdout, stderr, _stdin = streams = 3.times.map { client.recv_io }
       [STDOUT, STDERR, STDIN].zip(streams).each { |a, b| a.reopen(b) }
 
       preload unless preloaded?
@@ -173,15 +177,25 @@ module Spring
         IGNORE_SIGNALS.each { |sig| trap(sig, "DEFAULT") }
         trap("TERM", "DEFAULT")
 
-        STDERR.puts "Running via Spring preloader in process #{Process.pid}" unless Spring.quiet
+        unless Spring.quiet
+          STDERR.puts "Running via Spring preloader in process #{Process.pid}"
+
+          if Rails.env.production?
+            STDERR.puts "WARNING: Spring is running in production. To fix "         \
+                        "this make sure the spring gem is only present "            \
+                        "in `development` and `test` groups in your Gemfile "       \
+                        "and make sure you always use "                             \
+                        "`bundle install --without development test` in production"
+          end
+        end
 
         ARGV.replace(args)
         $0 = command.exec_name
 
-        # Delete all env vars which are unchanged from before spring started
+        # Delete all env vars which are unchanged from before Spring started
         original_env.each { |k, v| ENV.delete k if ENV[k] == v }
 
-        # Load in the current env vars, except those which *were* changed when spring started
+        # Load in the current env vars, except those which *were* changed when Spring started
         env.each { |k, v| ENV[k] ||= v }
 
         # requiring is faster, so if config.cache_classes was true in
