@@ -7,6 +7,7 @@ module Spring
       @spring_env = spring_env
       @mutex      = Mutex.new
       @state      = :running
+      @pid        = nil
     end
 
     def log(message)
@@ -92,7 +93,7 @@ module Spring
     def start_child(preload = false)
       @child, child_socket = UNIXSocket.pair
 
-      Bundler.with_clean_env do
+      Bundler.with_original_env do
         @pid = Process.spawn(
           {
             "RAILS_ENV"           => app_env,
